@@ -12,11 +12,19 @@ module DelayedJob
     source_paths << File.join(File.dirname(__FILE__), "templates")
 
     def create_migration_file
-      migration_template "migration.rb", "db/migrate/create_delayed_jobs.rb"
+      migration_template "migration.rb", "db/migrate/create_delayed_jobs.rb", migration_version: migration_version
     end
 
     def self.next_migration_number(dirname)
       ActiveRecord::Generators::Base.next_migration_number dirname
     end
+
+    private
+
+    def migration_version
+      if ActiveRecord::VERSION::MAJOR >= 5
+        "[#{ActiveRecord::VERSION::MAJOR}.#{ActiveRecord::VERSION::MINOR}]"
+      end
+    end
   end
 end
